@@ -27,7 +27,7 @@ class MsClient(AbstractClient):
 
 
     def CancelEncryptTask(self, request):
-        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制，取消渠道合作加固中的任务。
+        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制，取消渠道合作加固中的任务
 
         :param request: Request instance for CancelEncryptTask.
         :type request: :class:`tencentcloud.ms.v20180408.models.CancelEncryptTaskRequest`
@@ -259,7 +259,7 @@ class MsClient(AbstractClient):
 
 
     def DescribeEncryptInstances(self, request):
-        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制，用于查询加固任务，入参中的条件过滤字段均为精准匹配。支持功能点：1. 多任务分页查询  2.根据任务Id唯一值查询单记录
+        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制，用于查询加固任务，入参中的条件过滤字段均为精准匹配。支持功能点: 1. 多任务分页查询  2.根据任务Id唯一值查询单记录
 
         :param request: Request instance for DescribeEncryptInstances.
         :type request: :class:`tencentcloud.ms.v20180408.models.DescribeEncryptInstancesRequest`
@@ -305,7 +305,7 @@ class MsClient(AbstractClient):
 
 
     def DescribeOrderInstances(self, request):
-        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制。 接口返回的结果为：创建订单后，订单审批状态信息，以及与订单关联的资源状态等信息，入参中的条件过滤字段均为精准匹配。
+        """该接口供渠道合作应用加固使用，接口调用有白名单用户限制。 接口返回的结果为：创建订单后，订单审批状态信息，以及与订单关联的资源状态等信息，入参中的条件过滤字段均为精准匹配.
         接口功能点：
         1.支持多订单分页查询；
         2.支持唯一订单号精准匹配查询；
@@ -470,8 +470,32 @@ class MsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DestroyResourceInstances(self, request):
+        """渠道合作资源销毁
+        安卓应用加固-按年收费资源销毁，其他类型暂不支持
+
+        :param request: Request instance for DestroyResourceInstances.
+        :type request: :class:`tencentcloud.ms.v20180408.models.DestroyResourceInstancesRequest`
+        :rtype: :class:`tencentcloud.ms.v20180408.models.DestroyResourceInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DestroyResourceInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.DestroyResourceInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RequestLocalTask(self, request):
-        """client任务请求地址
+        """client任务请求
 
         :param request: Request instance for RequestLocalTask.
         :type request: :class:`tencentcloud.ms.v20180408.models.RequestLocalTaskRequest`
@@ -494,7 +518,7 @@ class MsClient(AbstractClient):
 
 
     def UpdateClientState(self, request):
-        """更新client状态
+        """更新client状态，需要白名单
 
         :param request: Request instance for UpdateClientState.
         :type request: :class:`tencentcloud.ms.v20180408.models.UpdateClientStateRequest`
@@ -517,7 +541,7 @@ class MsClient(AbstractClient):
 
 
     def UpdateLocalTaskResult(self, request):
-        """更新本地任务结果
+        """更新本地任务执行结果
 
         :param request: Request instance for UpdateLocalTaskResult.
         :type request: :class:`tencentcloud.ms.v20180408.models.UpdateLocalTaskResultRequest`
